@@ -20,13 +20,15 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 675 Mass Ave, Cambridge, MA 02139, USA.
 
-using namespace std;
+namespace std {} using namespace std;
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include <stdio.h>
+#include <cstring>
+
 #include "common.h"
 #include "SpewConsole.h"
 
@@ -209,6 +211,7 @@ void SpewConsole::intermediateStatistics(
 /////////////////  SpewConsole::cumulativeStatistics()  ///////////////////////
 void SpewConsole::cumulativeStatistics(capacity_t jobBytesTransferred,
                                        const TimeHack& jobTransferTime,
+                                       capacity_t jobOps,
                                        capacity_t totalBytesRead,
                                        const TimeHack& totalReadTransferTime,
                                        capacity_t totalReadOps,
@@ -224,24 +227,24 @@ void SpewConsole::cumulativeStatistics(capacity_t jobBytesTransferred,
 
    if (mIterationsToDo != 1)
    {
-      printf("Itereration: %8d    Total runtime: %s\n",
+      printf("Iteration: %8d    Total runtime: %s\n",
              mCurrentIteration, totalRunTime.getElapsedTimeStr().c_str());     
    }
    switch (mCurrentIoDirection)
    {
    case READING:
-      printf("RTR: %11.2Lf %-5s   Tranfser time: %s    IOPS: %11.2Lf\n",
+      printf("RTR: %11.2Lf %-5s   Transfer time: %s    IOPS: %11.2Lf\n",
              transferRate, 
              getTransferRateUnitsStr(mCurrentUnits), 
              jobTransferTime.getElapsedTimeStr().c_str(),
-             (long double)totalReadOps/(long double)jobTransferTime.getTime());  
+             (long double)jobOps/(long double)jobTransferTime.getTime());  
       break;
    case WRITING:
       printf("WTR: %11.2Lf %-5s   Transfer time: %s    IOPS: %11.2Lf\n",
              transferRate, 
              getTransferRateUnitsStr(mCurrentUnits), 
              jobTransferTime.getElapsedTimeStr().c_str(),
-             (long double)totalWriteOps/(long double)jobTransferTime.getTime());  
+             (long double)jobOps/(long double)jobTransferTime.getTime());  
       break;
    }
    fflush(stdout);
