@@ -20,7 +20,7 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 675 Mass Ave, Cambridge, MA 02139, USA.
 
-using namespace std;
+namespace std {} using namespace std;
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -378,6 +378,7 @@ void SpewTui::intermediateStatistics(capacity_t hackRowBytesTransferred,
 /////////////////////  SpewTui::cumulativeStatistics() ////////////////////////
 void SpewTui::cumulativeStatistics(capacity_t jobBytesTransferred,
                                    const TimeHack& jobTransferTime,
+                                   capacity_t jobOps,
                                    capacity_t totalBytesRead,
                                    const TimeHack& totalReadTransferTime,
                                    capacity_t totalReadOps,
